# UpToPeriodsTypeProductRatePlanChargeRest

The period type used to define when the charge ends.  **Notes**:   - You must use this field together with the `UpToPeriods` field to specify the time period.  - This field is applicable only when the `EndDateCondition` field is set to `FixedPeriod`.  

## Enum

* `BILLING_PERIODS` (value: `'Billing Periods'`)

* `DAYS` (value: `'Days'`)

* `WEEKS` (value: `'Weeks'`)

* `MONTHS` (value: `'Months'`)

* `YEARS` (value: `'Years'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


